import React, { useRef, useState, useEffect } from 'react';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faChevronRight, faChevronDown, faTimes } from '@fortawesome/free-solid-svg-icons';

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var _excluded = ["submenus", "dropdown", "depthLevel"];
var DropDown = function DropDown(_ref) {
  var submenus = _ref.submenus,
      dropdown = _ref.dropdown,
      depthLevel = _ref.depthLevel,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  depthLevel = depthLevel + 1;
  var dropdownClass = depthLevel > 1 ? "dropdown-submenu" : "";
  return React.createElement("ul", Object.assign({
    className: "dropdown " + dropdownClass + " " + (dropdown ? 'show' : '')
  }, props), submenus.map(function (submenu, index) {
    return React.createElement(MenuItems, {
      items: submenu,
      key: index,
      depthLevel: depthLevel
    });
  }));
};

var _excluded$1 = ["items", "depthLevel"];
var MenuItems = function MenuItems(_ref) {
  var items = _ref.items,
      depthLevel = _ref.depthLevel,
      props = _objectWithoutPropertiesLoose(_ref, _excluded$1);

  //console.log(items)
  var ref = useRef(null);

  var _useState = useState(false),
      dropdown = _useState[0],
      setDropdown = _useState[1];

  useEffect(function () {
    var handler = function handler(event) {
      if (dropdown && ref.current && !ref.current.contains(event.target)) {
        setDropdown(false);
      }
    };

    document.addEventListener("mousedown", handler);
    document.addEventListener("touchstart", handler);
    return function () {
      document.removeEventListener("mousedown", handler);
      document.removeEventListener("touchstart", handler);
    };
  }, [dropdown]);
  return React.createElement("li", Object.assign({
    className: 'menu-items'
  }, props, {
    ref: ref
  }), items.submenu ? React.createElement(React.Fragment, null, React.createElement("button", {
    type: 'button',
    "aria-haspopup": "menu",
    "aria-expanded": dropdown ? 'true' : 'false',
    onClick: function onClick() {
      return setDropdown(function (prev) {
        return !prev;
      });
    }
  }, React.createElement("span", {
    className: "buttonLayout"
  }, React.createElement("span", null, React.createElement("span", {
    style: {
      display: 'flex',
      gap: '8px'
    }
  }, React.createElement("span", null, items.icon ? React.createElement(FontAwesomeIcon, {
    icon: items.icon
  }) : ''), React.createElement("span", null, items.title, " "))), React.createElement("span", null, depthLevel > 0 ? React.createElement("span", null, React.createElement(FontAwesomeIcon, {
    icon: faChevronRight
  })) : React.createElement("span", null, React.createElement(FontAwesomeIcon, {
    icon: faChevronDown
  }))))), React.createElement(DropDown, {
    submenus: items.submenu,
    dropdown: dropdown,
    depthLevel: depthLevel
  })) : React.createElement("button", {
    className: "singleMenuItem",
    style: items.style,
    onClick: items.action
  }, React.createElement("span", {
    style: {
      display: 'flex',
      gap: '8px'
    }
  }, React.createElement("span", null, items.icon ? React.createElement(FontAwesomeIcon, {
    icon: items.icon
  }) : ''), React.createElement("span", null, items.title)), React.createElement("span", null)));
};

var _excluded$2 = ["menuItems"];
/** A Navigation bar with a multilevel dynamic dropdown menu. */

var NavBar = function NavBar(_ref) {
  var _ref$menuItems = _ref.menuItems,
      menuItems = _ref$menuItems === void 0 ? [{
    icon: faTimes,
    title: "No menus found"
  }] : _ref$menuItems,
      props = _objectWithoutPropertiesLoose(_ref, _excluded$2);

  //console.warn(menuItems)
  var depthLevel = 0;
  return React.createElement("div", Object.assign({
    className: 'nav-area'
  }, props), React.createElement("nav", null, React.createElement("ul", {
    className: 'menus'
  }, menuItems.map(function (menu, index) {
    return React.createElement(MenuItems, {
      items: menu,
      key: index,
      depthLevel: depthLevel
    });
  }))));
};

export { NavBar };
//# sourceMappingURL=normalyze-react.esm.js.map
